summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorYann E. MORIN" <yann.morin.1998@anciens.enib.fr>2007-04-18 11:55:52 (GMT)
committerYann E. MORIN" <yann.morin.1998@anciens.enib.fr>2007-04-18 11:55:52 (GMT)
commit66bc1c8896b7b0ff925758abb7f7c76a408e2ba8 (patch)
treeee83e2300b3b84ef6636bbecfd2602d162d5c60d
parent5b96251953f0974a23ffaae3ce04781b3a3f23e7 (diff)
Try to further fix using of the build and/or host tools for binutils to build properly.
-rw-r--r--scripts/buildToolchain.sh6
1 files changed, 4 insertions, 2 deletions
diff --git a/scripts/buildToolchain.sh b/scripts/buildToolchain.sh
index bfbf88d..0c2a587 100644
--- a/scripts/buildToolchain.sh
+++ b/scripts/buildToolchain.sh
@@ -72,12 +72,14 @@ case "${CT_KERNEL},${CT_CANADIAN}" in
*) CT_HOST="`echo \"${CT_HOST}\" |sed -r -e 's/-/-host_/;'`";;
esac
# Ah! Recent versions of binutils need some of the build system (read CT_BUILD)
# tools to be accessible (ar is but an example). Do that:
CT_DoLog EXTRA "Making build system tools available"
mkdir -p "${CT_PREFIX_DIR}/bin"
for tool in ar; do
ln -s "`which ${tool}`" "${CT_PREFIX_DIR}/bin/${CT_BUILD}-${tool}"
+ ln -s "`which ${tool}`" "${CT_PREFIX_DIR}/bin/${CT_HOST}-${tool}"
done
# Ha. cygwin host have an .exe suffix (extension) for executables.
@@ -72,12 +72,14 @@ case "${CT_KERNEL},${CT_CANADIAN}" in
*) CT_HOST="`echo \"${CT_HOST}\" |sed -r -e 's/-/-host_/;'`";;
esac
-# Ah! Recent versions of binutils need some of the build system (read CT_BUILD)
-# tools to be accessible (ar is but an example). Do that:
+# Ah! Recent versions of binutils need some of the build and/or host system
+# (read CT_BUILD and CT_HOST) tools to be accessible (ar is but an example).
+# Do that:
CT_DoLog EXTRA "Making build system tools available"
mkdir -p "${CT_PREFIX_DIR}/bin"